Module ast

Module ast 

AST module.

Python Ast

This module provides python ast functionality for the Oaks project.

Structs

Comprehension
Represents a comprehension in a list/dict/set/generator.
ExceptHandler
Represents an exception handler in a try statement.
ImportName
Represents a name in an import statement.
Keyword
Represents a keyword argument.
MatchCase
Represents a case in a match statement.
Parameter
Represents a function parameter.
Program
A Python program consisting of a list of statements.
PythonRoot
Root node of a Python source file.
WithItem
Represents an item in a with statement.

Enums

AugmentedOperator
Represents an augmented assignment operator.
BinaryOperator
Represents a binary operator.
BoolOperator
Represents a boolean operator.
CompareOperator
Represents a comparison operator.
Expression
Represents a Python expression.
Literal
Represents a literal value.
Pattern
Represents a pattern in a match case.
Statement
Represents a Python statement.
Type
Represents a type annotation.
UnaryOperator
Represents a unary operator.