PythonTokenType

Enum PythonTokenType 

#[repr(u16)]
pub enum PythonTokenType {
Show 93 variants Whitespace = 0, Comment = 1, Identifier = 2, Number = 3, String = 4, Bytes = 5, FString = 6, AndKeyword = 7, AsKeyword = 8, AssertKeyword = 9, AsyncKeyword = 10, AwaitKeyword = 11, BreakKeyword = 12, ClassKeyword = 13, ContinueKeyword = 14, DefKeyword = 15, DelKeyword = 16, ElifKeyword = 17, ElseKeyword = 18, ExceptKeyword = 19, FalseKeyword = 20, FinallyKeyword = 21, ForKeyword = 22, FromKeyword = 23, GlobalKeyword = 24, IfKeyword = 25, ImportKeyword = 26, InKeyword = 27, IsKeyword = 28, LambdaKeyword = 29, NoneKeyword = 30, NonlocalKeyword = 31, NotKeyword = 32, OrKeyword = 33, PassKeyword = 34, RaiseKeyword = 35, ReturnKeyword = 36, TrueKeyword = 37, TryKeyword = 38, WhileKeyword = 39, WithKeyword = 40, YieldKeyword = 41, Plus = 42, Minus = 43, Star = 44, DoubleStar = 45, Slash = 46, DoubleSlash = 47, Percent = 48, At = 49, LeftShift = 50, RightShift = 51, Ampersand = 52, Pipe = 53, Caret = 54, Tilde = 55, Less = 56, Greater = 57, LessEqual = 58, GreaterEqual = 59, Equal = 60, NotEqual = 61, Assign = 62, PlusAssign = 63, MinusAssign = 64, StarAssign = 65, DoubleStarAssign = 66, SlashAssign = 67, DoubleSlashAssign = 68, PercentAssign = 69, AtAssign = 70, AmpersandAssign = 71, PipeAssign = 72, CaretAssign = 73, LeftShiftAssign = 74, RightShiftAssign = 75, LeftParen = 76, RightParen = 77, LeftBracket = 78, RightBracket = 79, LeftBrace = 80, RightBrace = 81, Comma = 82, Colon = 83, Semicolon = 84, Dot = 85, Arrow = 86, Ellipsis = 87, Newline = 88, Indent = 89, Dedent = 90, Eof = 91, Error = 92,
}
Python token types.

Variants



Whitespace = 0

Whitespace



Comment = 1

Comment



Identifier = 2

Identifier



Number = 3

Number literal



String = 4

String literal



Bytes = 5

Bytes literal



FString = 6

Formatted string literal



AndKeyword = 7

and



AsKeyword = 8

as



AssertKeyword = 9

assert



AsyncKeyword = 10

async



AwaitKeyword = 11

await



BreakKeyword = 12

break



ClassKeyword = 13

class



ContinueKeyword = 14

continue



DefKeyword = 15

def



DelKeyword = 16

del



ElifKeyword = 17

elif



ElseKeyword = 18

else



ExceptKeyword = 19

except



FalseKeyword = 20

False



FinallyKeyword = 21

finally



ForKeyword = 22

for



FromKeyword = 23

from



GlobalKeyword = 24

global



IfKeyword = 25

if



ImportKeyword = 26

import



InKeyword = 27

in



IsKeyword = 28

is



LambdaKeyword = 29

lambda



NoneKeyword = 30

None



NonlocalKeyword = 31

nonlocal



NotKeyword = 32

not



OrKeyword = 33

or



PassKeyword = 34

pass



RaiseKeyword = 35

raise



ReturnKeyword = 36

return



TrueKeyword = 37

True



TryKeyword = 38

try



WhileKeyword = 39

while



WithKeyword = 40

with



YieldKeyword = 41

yield



Plus = 42

+



Minus = 43

-



Star = 44

*



DoubleStar = 45

**



Slash = 46

/



DoubleSlash = 47

//



Percent = 48

%



At = 49

@



LeftShift = 50

<<



RightShift = 51

>>



Ampersand = 52

&



Pipe = 53

|



Caret = 54

^



Tilde = 55

~



Less = 56

<



Greater = 57

>



LessEqual = 58

<=



GreaterEqual = 59

>=



Equal = 60

==



NotEqual = 61

!=



Assign = 62

=



PlusAssign = 63

+=



MinusAssign = 64

-=



StarAssign = 65

*=



DoubleStarAssign = 66

**=



SlashAssign = 67

/=



DoubleSlashAssign = 68

//=



PercentAssign = 69

%=



AtAssign = 70

@=



AmpersandAssign = 71

&=



PipeAssign = 72

|=



CaretAssign = 73

^=



LeftShiftAssign = 74

<<=



RightShiftAssign = 75

>>=



LeftParen = 76

(



RightParen = 77

)



LeftBracket = 78

[



RightBracket = 79

]



LeftBrace = 80

{



RightBrace = 81

}



Comma = 82

,



Colon = 83

:



Semicolon = 84

;



Dot = 85

.



Arrow = 86

->



Ellipsis = 87

...



Newline = 88

Newline



Indent = 89

Indent



Dedent = 90

Dedent



Eof = 91

End of stream



Error = 92

Error token

Implementations

Source

impl PythonTokenType

pub fn is_keyword(&self) -> bool

Returns true if the token type is a keyword.

Source

impl PythonTokenType

pub fn is_trivia(&self) -> bool

Returns true if the token type is a trivia (whitespace or comment).