PythonElementType

Enum PythonElementType 

#[repr(u16)]
pub enum PythonElementType {
Show 173 variants Whitespace = 0, Comment = 1, Identifier = 2, Number = 3, String = 4, Bytes = 5, FString = 6, AndKeyword = 7, AsKeyword = 8, AssertKeyword = 9, AsyncKeyword = 10, AwaitKeyword = 11, BreakKeyword = 12, ClassKeyword = 13, ContinueKeyword = 14, DefKeyword = 15, DelKeyword = 16, ElifKeyword = 17, ElseKeyword = 18, ExceptKeyword = 19, FalseKeyword = 20, FinallyKeyword = 21, ForKeyword = 22, FromKeyword = 23, GlobalKeyword = 24, IfKeyword = 25, ImportKeyword = 26, InKeyword = 27, IsKeyword = 28, LambdaKeyword = 29, NoneKeyword = 30, NonlocalKeyword = 31, NotKeyword = 32, OrKeyword = 33, PassKeyword = 34, RaiseKeyword = 35, ReturnKeyword = 36, TrueKeyword = 37, TryKeyword = 38, WhileKeyword = 39, WithKeyword = 40, YieldKeyword = 41, Plus = 42, Minus = 43, Star = 44, DoubleStar = 45, Slash = 46, DoubleSlash = 47, Percent = 48, At = 49, LeftShift = 50, RightShift = 51, Ampersand = 52, Pipe = 53, Caret = 54, Tilde = 55, Less = 56, Greater = 57, LessEqual = 58, GreaterEqual = 59, Equal = 60, NotEqual = 61, Assign = 62, PlusAssign = 63, MinusAssign = 64, StarAssign = 65, DoubleStarAssign = 66, SlashAssign = 67, DoubleSlashAssign = 68, PercentAssign = 69, AtAssign = 70, AmpersandAssign = 71, PipeAssign = 72, CaretAssign = 73, LeftShiftAssign = 74, RightShiftAssign = 75, LeftParen = 76, RightParen = 77, LeftBracket = 78, RightBracket = 79, LeftBrace = 80, RightBrace = 81, Comma = 82, Colon = 83, Semicolon = 84, Dot = 85, Arrow = 86, Ellipsis = 87, Newline = 88, Indent = 89, Dedent = 90, Eof = 91, Error = 92, Root = 93, Module = 94, InteractiveModule = 95, ExpressionModule = 96, Name = 97, Constant = 98, JoinedStr = 99, Expr = 100, Tuple = 101, GeneratorExp = 102, List = 103, ListComp = 104, Dict = 105, DictComp = 106, SetComp = 107, Set = 108, UnaryOp = 109, Keyword = 110, Starred = 111, Call = 112, Slice = 113, Subscript = 114, Attribute = 115, BinOp = 116, BoolOp = 117, Compare = 118, IfExp = 119, Lambda = 120, Yield = 121, YieldFrom = 122, NamedExpr = 123, FormattedValue = 124, Await = 125, Suite = 126, Decorator = 127, AssignStmt = 128, WithItem = 129, Return = 130, ReturnStmt = 131, Pass = 132, PassStmt = 133, Break = 134, BreakStmt = 135, Continue = 136, ContinueStmt = 137, Global = 138, GlobalStmt = 139, Nonlocal = 140, NonlocalStmt = 141, Assert = 142, AssertStmt = 143, If = 144, IfStmt = 145, While = 146, WhileStmt = 147, For = 148, ForStmt = 149, AsyncFor = 150, Try = 151, TryStmt = 152, ExceptHandler = 153, With = 154, WithStmt = 155, AsyncWith = 156, FunctionDef = 157, AsyncFunctionDef = 158, ClassDef = 159, Import = 160, ImportFrom = 161, ImportStmt = 162, ImportFromStmt = 163, ExprStmt = 164, Delete = 165, DeleteStmt = 166, Raise = 167, RaiseStmt = 168, Arguments = 169, Arg = 170, Alias = 171, Comprehension = 172,
}
Python element types.

Variants



Whitespace = 0

Whitespace



Comment = 1

Comment



Identifier = 2

Identifier



Number = 3

Number literal



String = 4

String literal



Bytes = 5

Bytes literal



FString = 6

Formatted string literal



AndKeyword = 7

and



AsKeyword = 8

as



AssertKeyword = 9

assert



AsyncKeyword = 10

async



AwaitKeyword = 11

await



BreakKeyword = 12

break



ClassKeyword = 13

class



ContinueKeyword = 14

continue



DefKeyword = 15

def



DelKeyword = 16

del



ElifKeyword = 17

elif



ElseKeyword = 18

else



ExceptKeyword = 19

except



FalseKeyword = 20

False



FinallyKeyword = 21

finally



ForKeyword = 22

for



FromKeyword = 23

from



GlobalKeyword = 24

global



IfKeyword = 25

if



ImportKeyword = 26

import



InKeyword = 27

in



IsKeyword = 28

is



LambdaKeyword = 29

lambda



NoneKeyword = 30

None



NonlocalKeyword = 31

nonlocal



NotKeyword = 32

not



OrKeyword = 33

or



PassKeyword = 34

pass



RaiseKeyword = 35

raise



ReturnKeyword = 36

return



TrueKeyword = 37

True



TryKeyword = 38

try



WhileKeyword = 39

while



WithKeyword = 40

with



YieldKeyword = 41

yield



Plus = 42

+



Minus = 43

-



Star = 44

*



DoubleStar = 45

**



Slash = 46

/



DoubleSlash = 47

//



Percent = 48

%



At = 49

@



LeftShift = 50

<<



RightShift = 51

>>



Ampersand = 52

&



Pipe = 53

|



Caret = 54

^



Tilde = 55

~



Less = 56

<



Greater = 57

>



LessEqual = 58

<=



GreaterEqual = 59

>=



Equal = 60

==



NotEqual = 61

!=



Assign = 62

=



PlusAssign = 63

+=



MinusAssign = 64

-=



StarAssign = 65

*=



DoubleStarAssign = 66

**=



SlashAssign = 67

/=



DoubleSlashAssign = 68

//=



PercentAssign = 69

%=



AtAssign = 70

@=



AmpersandAssign = 71

&=



PipeAssign = 72

|=



CaretAssign = 73

^=



LeftShiftAssign = 74

<<=



RightShiftAssign = 75

>>=



LeftParen = 76

(



RightParen = 77

)



LeftBracket = 78

[



RightBracket = 79

]



LeftBrace = 80

{



RightBrace = 81

}



Comma = 82

,



Colon = 83

:



Semicolon = 84

;



Dot = 85

.



Arrow = 86

->



Ellipsis = 87

...



Newline = 88

Newline



Indent = 89

Indent



Dedent = 90

Dedent



Eof = 91

End of stream



Error = 92

Error node



Root = 93

Root node



Module = 94

Module



InteractiveModule = 95

Interactive module



ExpressionModule = 96

Expression module



Name = 97

Name expression



Constant = 98

Constant expression



JoinedStr = 99

Joined string expression



Expr = 100

Expression



Tuple = 101

Tuple expression



GeneratorExp = 102

Generator expression



List = 103

List expression



ListComp = 104

List comprehension



Dict = 105

Dictionary expression



DictComp = 106

Dictionary comprehension



SetComp = 107

Set comprehension



Set = 108

Set expression



UnaryOp = 109

Unary operation



Keyword = 110

Keyword argument



Starred = 111

Starred expression



Call = 112

Call expression



Slice = 113

Slice expression



Subscript = 114

Subscript expression



Attribute = 115

Attribute expression



BinOp = 116

Binary operation



BoolOp = 117

Boolean operation



Compare = 118

Comparison expression



IfExp = 119

If expression



Lambda = 120

Lambda expression



Yield = 121

Yield expression



YieldFrom = 122

Yield from expression



NamedExpr = 123

Named expression (walrus operator)



FormattedValue = 124

Formatted value expression



Await = 125

Await expression



Suite = 126

Suite of statements



Decorator = 127

Decorator



AssignStmt = 128

Assignment statement



WithItem = 129

With item



Return = 130

Return statement (keyword)



ReturnStmt = 131

Return statement



Pass = 132

Pass statement (keyword)



PassStmt = 133

Pass statement



Break = 134

Break statement (keyword)



BreakStmt = 135

Break statement



Continue = 136

Continue statement (keyword)



ContinueStmt = 137

Continue statement



Global = 138

Global statement (keyword)



GlobalStmt = 139

Global statement



Nonlocal = 140

Nonlocal statement (keyword)



NonlocalStmt = 141

Nonlocal statement



Assert = 142

Assert statement (keyword)



AssertStmt = 143

Assert statement



If = 144

If statement (keyword)



IfStmt = 145

If statement



While = 146

While statement (keyword)



WhileStmt = 147

While statement



For = 148

For statement (keyword)



ForStmt = 149

For statement



AsyncFor = 150

Async for statement



Try = 151

Try statement (keyword)



TryStmt = 152

Try statement



ExceptHandler = 153

Except handler



With = 154

With statement (keyword)



WithStmt = 155

With statement



AsyncWith = 156

Async with statement



FunctionDef = 157

Function definition



AsyncFunctionDef = 158

Async function definition



ClassDef = 159

Class definition



Import = 160

Import statement (keyword)



ImportFrom = 161

Import from statement (keyword)



ImportStmt = 162

Import statement



ImportFromStmt = 163

Import from statement



ExprStmt = 164

Expression statement



Delete = 165

Delete statement (keyword)



DeleteStmt = 166

Delete statement



Raise = 167

Raise statement (keyword)



RaiseStmt = 168

Raise statement



Arguments = 169

Arguments list



Arg = 170

Single argument



Alias = 171

Import alias



Comprehension = 172

Comprehension

Implementations

Source

impl PythonElementType

pub fn is_keyword(&self) -> bool

Returns true if the element type is a keyword.

Source

impl PythonElementType

pub fn is_trivia(&self) -> bool

Returns true if the element type is a trivia (whitespace or comment).